ContiguousBitSet

Struct ContiguousBitSet 

pub struct ContiguousBitSet { /* private fields */ }
A dense, contiguous bitset.

ContiguousBitSet is designed for tracking set membership of dense, contiguous values, such as the indexes of values in a vector. It is able to hold up to 128 values (indices 0–127) inline with no heap allocation. It is not suitable for sparse values (values that are far apart in value) as the size of the underlying storage will tied to the largest value in the set: roughly ((max_value / 64) + 1) * 8 bytes.

All operations are O(1) with the exception of set when setting a bit that extends beyond the current capacity, which will require a heap allocation.

Implementations

Source

impl ContiguousBitSet

pub fn new() -> Self

Creates a new, empty bitset with no bits set.

pub fn len(&self) -> usize

Returns the number of bits that are set.

pub fn is_empty(&self) -> bool

Returns false if no bits are set.

pub fn set(&mut self, index: usize)

Sets the bit at index.

pub fn clear(&mut self, index: usize)

Clears the bit at index.

If index is beyond the current capacity, this is a no-op.

pub fn is_set(&self, index: usize) -> bool

Returns true if the bit at index is set.

pub fn clear_all(&mut self)

Clears all bits, resetting the bitset to its initial empty state.

All existing capacity is retained.