pub type FastIndexSet<K> = IndexSet<K, FastBuildHasher>;Expand description
A hash set with stable insertion order based on indexset (IndexSet) using FastHasher.
Aliased Type
pub struct FastIndexSet<K> { /* private fields */ }pub type FastIndexSet<K> = IndexSet<K, FastBuildHasher>;A hash set with stable insertion order based on indexset (IndexSet) using FastHasher.
pub struct FastIndexSet<K> { /* private fields */ }