pub struct ContiguousBitSet { /* private fields */ }Expand description
A dense, contiguous bitset.
ContiguousBitSet is designed for tracking set membership of dense, contiguous values, such as the indexes of
values in a vector. It is able to hold up to 128 values (indices 0–127) inline with no heap allocation. It is not
suitable for sparse values (values that are far apart in value) as the size of the underlying storage will tied to
the largest value in the set: roughly ((max_value / 64) + 1) * 8 bytes.
All operations are O(1) with the exception of set when setting a bit that extends beyond the current capacity,
which will require a heap allocation.
Implementations